.. cryoswath documentation master file, created by
   sphinx-quickstart on Wed Sep 11 11:18:27 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to cryoswath's documentation!
=====================================

Find the associated GitHub repository at https://github.com/j-haacker/cryoswath.
To set up a working/testing environment, follow the steps discribed in :doc:`prerequisites`.
See the quickstart guide in :doc:`Getting started <getting_started>`, if needed.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   prerequisites
   getting_started
   tutorials
   tests
   cryoswath.l1b
   cryoswath.l2
   cryoswath.l3
   cryoswath.l4
   cryoswath.misc
   cryoswath.gis
   cryoswath.test_plots
